# Pygilent

Pygilent is a Python package for interacting with Agilent ICP-MS instruments (tested on Agilent 7500, 8800, and 8900 outputs). It provides a convenient and easy-to-use interface for importing, collating, and processing data from Agilent ICP-MS instruments in your Python scripts.

## Features

- Import batch data from Agilent output folders (csv outputs) or an archive database.
- Perform processing on the batch using the new Batch class.
- Currently able to process data for trace-element ratios.

## Useage

See examples directory for useful examples. 